def add_numbers(num1, num2):
    results = num1 + num2
    return f'{results}'


def subtract_numbers(num1, num2):
    results = num1 - num2
    return f'{results}'


def multiply_numbers(num1, num2):
    results = num1 * num2
    return f'{results}'


def divide_numbers_float(num1, num2):
    results = num1 / num2
    return f'{results}'


def divide_numbers_floor(num1, num2):
    results = num1 // num2
    return f'{results}'


def power_numbers(num1, num2):
    results = num1 ** num2
    return f'{results}'


def mode_numbers(num1, num2):
    results = num1 % num2
    return f'{results}'
